@@ -17,16 +17,16 @@ along with searx. If not, see < http://www.gnu.org/licenses/ >.
 '''
 
 from os.path import realpath, dirname, splitext, join
+import sys
 from imp import load_source
-import grequests
 from itertools import izip_longest, chain
 from operator import itemgetter
 from urlparse import urlparse
+from datetime import datetime
+import grequests
+from flask.ext.babel import gettext
 from searx import settings
 from searx.utils import gen_useragent
-import sys
-from datetime import datetime
-from flask.ext.babel import gettext
 
 engine_dir = dirname(realpath(__file__))
 
@@ -36,6 +36,8 @@ engines = {}
 
 categories = {'general': []}
 
+engine_shortcuts = {}
+
 
 def load_module(filename):
     modname = splitext(filename)[0]
@@ -53,6 +55,7 @@ if not 'engines' in settings or not settings['engines']:
 for engine_data in settings['engines']:
     engine_name = engine_data['engine']
     engine = load_module(engine_name + '.py')
+
     for param_name in engine_data:
         if param_name == 'engine':
             continue
@@ -64,12 +67,30 @@ for engine_data in settings['engines']:
                     str.strip, engine_data['categories'].split(','))
             continue
         setattr(engine, param_name, engine_data[param_name])
+
+    if not hasattr(engine, 'paging'):
+        engine.paging = False
+
+    if not hasattr(engine, 'language_support'):
+        #engine.language_support = False
+        engine.language_support = True
+
+    if not hasattr(engine, 'timeout'):
+        #engine.language_support = False
+        engine.timeout = settings['server']['request_timeout']
+
+    if not hasattr(engine, 'shortcut'):
+        #engine.shortcut = '''
+        engine.shortcut = ''
+
+    # checking required variables
     for engine_attr in dir(engine):
         if engine_attr.startswith('_'):
             continue
         if getattr(engine, engine_attr) is None:
             print '[E] Engine config error: Missing attribute "{0}.{1}"'.format(engine.name, engine_attr)  # noqa
             sys.exit(1)
+
     engines[engine.name] = engine
     engine.stats = {
         'result_count': 0,
@@ -78,12 +99,17 @@ for engine_data in settings['engines']:
         'score_count': 0,
         'errors': 0
     }
+
     if hasattr(engine, 'categories'):
         for category_name in engine.categories:
             categories.setdefault(category_name, []).append(engine)
     else:
         categories['general'].append(engine)
 
+    if engine.shortcut:
+        # TODO check duplications
+        engine_shortcuts[engine.shortcut] = engine.name
+
 
 def default_request_params():
     return {
@@ -141,7 +167,7 @@ def score_results(results):
                 duplicated = new_res
                 break
         if duplicated:
-            if len(res.get('content', '')) > len(duplicated.get('content', '')):  # noqa
+            if res.get('content') > duplicated.get('content'):
                 duplicated['content'] = res['content']
             duplicated['score'] += score
             duplicated['engines'].append(res['engine'])
@@ -156,7 +182,7 @@ def score_results(results):
     return sorted(results, key=itemgetter('score'), reverse=True)
 
 
-def search(query, request, selected_engines):
+def search(query, request, selected_engines, pageno=1, lang='all'):
     global engines, categories, number_of_searches
     requests = []
     results = {}
@@ -171,11 +197,19 @@ def search(query, request, selected_engines):
 
         engine = engines[selected_engine['name']]
 
+        if pageno > 1 and not engine.paging:
+            continue
+
+        if lang != 'all' and not engine.language_support:
+            continue
+
         request_params = default_request_params()
         request_params['headers']['User-Agent'] = user_agent
         request_params['category'] = selected_engine['category']
         request_params['started'] = datetime.now()
-        request_params = engine.request(query, request_params)
+        request_params['pageno'] = pageno
+        request_params['language'] = lang
+        request_params = engine.request(query.encode('utf-8'), request_params)
 
         callback = make_callback(
             selected_engine['name'],
@@ -189,7 +223,7 @@ def search(query, request, selected_engines):
             headers=request_params['headers'],
             hooks=dict(response=callback),
             cookies=request_params['cookies'],
-            timeout=settings['server']['request_timeout']
+            timeout=engine.timeout
         )
 
         if request_params['method'] == 'GET':
