@@ -5,12 +5,15 @@ categories = ['music']
 
 guest_client_id = 'b45b1aa10f1ac2941910a7f0d10f8e28'
 url = 'https://api.soundcloud.com/'
-search_url = url + 'search?{query}&facet=model&limit=20&offset=0&linked_partitioning=1&client_id='+guest_client_id  # noqa
+search_url = url + 'search?{query}&facet=model&limit=20&offset={offset}&linked_partitioning=1&client_id='+guest_client_id  # noqa
+
+paging = True
 
 
 def request(query, params):
-    global search_url
-    params['url'] = search_url.format(query=urlencode({'q': query}))
+    offset = (params['pageno'] - 1) * 20
+    params['url'] = search_url.format(query=urlencode({'q': query}),
+                                      offset=offset)
     return params
 
 
